@@ -9,7 +9,7 @@
 
 #define DOSENV_SIZE 4096
 // #define RAW_TTY       /* requires for good INT 16h emulation */
-
+// #define ALLOW_IO      /* allow PORT I/O */
 
 #include <stdio.h>
 #include <string.h>
@@ -21,6 +21,10 @@
 
 #include "lrmi.h"
 
+#ifndef environ
+  extern char **environ;
+#endif
+
 extern int DTA_ofs,DTA_seg;
 
 char * path_u2d(char *p,char *newpath);
@@ -178,7 +182,7 @@ int i;
     struct termios tio_orig,tio_new;
 #endif
 
-    puts("\nDOS Runner v0.4  *  (C) 1999 by Arpad Gereoffy  <arpi@banki1.banki.hu>");
+    puts("\nDOS Runner v0.41  *  (C) 1999 by Arpad Gereoffy  <arpi@banki1.banki.hu>");
     puts("based on Linux Real Mode Interface by Josh Vanderhoof");
     puts("This software has NO WARRANTY.  Use it at your own risk.\n");
 
@@ -196,10 +200,10 @@ int i;
     tcsetattr(0,TCSANOW,&tio_new);
 #endif
         
-/*
+#ifdef ALLOW_IO
 	ioperm(0, 0x400, 1);
 	iopl(3);
-*/
+#endif
 	
 	run_vm86_EXE(argv[1],argc-2,&argv[2]);
 	
