@@ -4,7 +4,7 @@ static int
 em_int16(struct vm86_regs *r){
 int ax=(r->eax & 0xffff);
 int ah=(ax>>8);
-#define SET_AX(x) r->eax = r->eax&0xffff0000 | (x)
+#define SET_AX(x) regX(r->eax) = (x)
 
   /* Wait for a key */
   if(ah==0 || ah==0x10){
@@ -37,7 +37,7 @@ int ah=(ax>>8);
 
   /* get shift state */
   if(ah==2 || ah==0x12){
-    r->eax=(r->eax&0xffffff00);   /* FIX IT! FAKE! */
+    regL(r->eax)=0;          /* FIX IT! FAKE! */
     return 1;
   }
 
