@@ -1,4 +1,4 @@
-/*  INT 21h emulation v0.3     (C) 1999. A'rpi/ESP-team  */
+/*  INT 21h emulation v0.41     (C) 1999. A'rpi/ESP-team  */
 /* Implemented:
 
   AH - function
@@ -72,7 +72,7 @@ static int em_int21(struct vm86_regs *r){
 int ax=(r->eax & 0xffff);
 int al=(ax&0xff);
 int ah=(ax>>8);
-#define SET_AX(x) r->eax = r->eax&0xffff0000 | x
+#define SET_AX(x) regX(r->eax) = (x)
 #define CLC r->eflags = r->eflags & (~1)
 #define STC r->eflags = r->eflags | 1
 
@@ -96,8 +96,8 @@ int ah=(ax>>8);
 
   /* Set int vector  AL=int DS:DX->int */
   if(ah==0x25){
-    unsigned short int *p; 
-    p=(unsigned short int *)(al*4);
+    word *p; 
+    p=(word *)(al*4);
     p[0]=r->edx & 0xffff;
     p[1]=r->ds;
     return 1;
@@ -105,9 +105,9 @@ int ah=(ax>>8);
 
   /* Get int vector  AL=int DS:DX->int */
   if(ah==0x35){
-    unsigned short int *p; 
-    p=(unsigned short int *)(al*4);
-    r->ebx=(r->ebx&0xffff0000) | p[0];
+    word *p; 
+    p=(word *)(al*4);
+    regX(r->ebx)=p[0];
     r->es=p[1];
     return 1;
   }
@@ -250,7 +250,7 @@ int ah=(ax>>8);
     int m=dosmem_alloc(size);
     if(m<=0){
       STC;
-      r->ebx=(r->ebx&0xffff0000) | (dosmem_largest()>>4);
+      regX(r->ebx)=(dosmem_largest()>>4);
     } else {
       CLC;
       SET_AX((m>>4));
@@ -270,7 +270,7 @@ int ah=(ax>>8);
     int m=dosmem_resize(r->es<<4,size);
     if(m<=0){
       STC;
-      r->ebx=(r->ebx&0xffff0000) | (dosmem_largest()>>4);
+      regX(r->ebx)=(dosmem_largest()>>4);
       SET_AX(8); /* ??? */
     } else {
       CLC;
@@ -284,9 +284,9 @@ int ah=(ax>>8);
     struct tm *y;
     time(&x);
     y=gmtime(&x);
-    r->ecx=(r->ecx & 0xffff0000) + (y->tm_year);
-    r->edx=(r->edx & 0xffff0000) + (y->tm_mon<<8) + (y->tm_mday);
-    r->eax=(r->eax & 0xffffff00) + (y->tm_wday);
+    regX(r->ecx)=(y->tm_year);
+    regX(r->edx)=(y->tm_mon<<8) + (y->tm_mday);
+    regL(r->eax)=(y->tm_wday);
     return 1;
   }
 
@@ -296,8 +296,8 @@ int ah=(ax>>8);
     struct tm *y;
     time(&x);
     y=gmtime(&x);
-    r->ecx=(r->ecx & 0xffff0000) + (y->tm_hour<<8) + (y->tm_min);
-    r->edx=(r->edx & 0xffff0000) + (y->tm_sec<<8) + 0;
+    regX(r->ecx)=(y->tm_hour<<8) + (y->tm_min);
+    regX(r->edx)=(y->tm_sec<<8) + 0;
     return 1;
   }
 
@@ -308,8 +308,8 @@ int ah=(ax>>8);
     struct stat s;
     if(fstat(r->ebx&0xffff,&s)==-1){ STC; SET_AX(errno);return 1;}
     y=gmtime(&s.st_mtime);
-    r->ecx=(r->ecx & 0xffff0000) + (y->tm_sec>>2) + (y->tm_min<<5) + (y->tm_hour<<11);
-    r->edx=(r->edx & 0xffff0000) + (y->tm_mday) + (y->tm_mon<<5) + ((y->tm_year-1980)<<9);
+    regX(r->ecx)=(y->tm_sec>>2) + (y->tm_min<<5) + (y->tm_hour<<11);
+    regX(r->edx)=(y->tm_mday) + (y->tm_mon<<5) + ((y->tm_year-1980)<<9);
     CLC;
     return 1;
   }
@@ -342,7 +342,7 @@ int ah=(ax>>8);
   /* get DTA address */
   if(ah==0x2F){
     r->es=DTA_seg;
-    r->ebx=(r->ebx&0xffff0000) | DTA_ofs;
+    regX(r->ebx)=DTA_ofs;
     return 1;
   }
 
@@ -355,7 +355,7 @@ int ah=(ax>>8);
 
   /* get switch char */
   if(ax==0x3700){
-    r->eax=(r->eax&0xffffff00) | '-';
+    regL(r->eax)='-';
     return 1;
   }
 
