@@ -3,7 +3,7 @@ Linux Real Mode Interface - A library of DPMI-like functions for Linux.
 
 Copyright (C) 1998 by Josh Vanderhoof
 
-Some modifications (memory, interrupts) done by Arpad Gereoffy
+Some modifications (memory, interrupts, signals) done by Arpad Gereoffy
 
 You are free to distribute and modify this file, as long as you
 do not remove this copyright notice and clearly label modified
@@ -30,6 +30,7 @@ This software has NO WARRANTY.  Use it at your own risk.
 #include <dirent.h>
 
 #include "lrmi.h"
+#include "rulez.h"
 
 #define REAL_MEM_BASE 	0x10000
 #define REAL_MEM_SIZE 	(0xA0000-REAL_MEM_BASE)
@@ -715,23 +716,27 @@ run_vm86(void)
 
 			if (v == RETURN_TO_32_INT) return 1;
 
-			if(v==0x21){
+			if(v==0x21){    /* DOS function call */
 			  int i=em_int21(&context.vm.regs);
 			  if(i==-1) return 1;
 			  continue;
 			}
-			if(v==0x16){
+			if(v==0x16){    /* Keyboard functions */
 			  int i=em_int16(&context.vm.regs);
 			  if(i==-1) return 1;
 			  continue;
 			}
 			
-			if(v==0x29){
+			if(v==0x29){    /* Fast write char (AL=asciicode) */
 			  putchar(context.vm.regs.eax & 0xff);
  			  continue;
 			}
 
-			printf("Interrupt: %x  (ax=0x%04X)\n",v,context.vm.regs.eax & 0xffff);
+			if(v==0x33){    /* mouse */
+ 			  continue;
+			}
+
+			if(v>=0x20) printf("Interrupt: %02Xh  (ax=0x%04X)\n",v,context.vm.regs.eax & 0xffff);
 			
 do_int:
 			pushw(context.vm.regs.eflags);
@@ -761,7 +766,7 @@ do_int:
 			break;
 
 		if (!emulate()){
-		    unsigned char* p=(unsigned char *)((unsigned int)context.vm.regs.cs << 4);
+		    byte *p=(byte *)((dword)context.vm.regs.cs << 4);
 	            p+=context.vm.regs.eip;
 		    if(p[0]==0xE4){
 		      /* IN AL,??h */
